.. README generated with readmemako.py (github.com/russianidiot/readme-mako.py) and .README dotfiles (github.com/russianidiot-dotfiles/.README)


.. image:: https://img.shields.io/badge/Language-Python-blue.svg?style=plastic
	:target: none

.. image:: https://img.shields.io/pypi/pyversions/public.svg
	:target: https://pypi.org/pypi/public

.. image:: https://img.shields.io/pypi/v/public.svg
	:target: https://pypi.org/pypi/public

|

.. image:: https://api.codacy.com/project/badge/Grade/535736e5a8d148369e9bc237238b3831
	:target: https://www.codacy.com/app/russianidiot/public-py

.. image:: https://codeclimate.com/github/russianidiot/public.py/badges/gpa.svg
	:target: https://codeclimate.com/github/russianidiot/public.py

.. image:: https://landscape.io/github/russianidiot/public.py/master/landscape.svg?style=flat
	:target: https://landscape.io/github/russianidiot/public.py

.. image:: https://scrutinizer-ci.com/g/russianidiot/public.py/badges/quality-score.png?b=master
	:target: https://scrutinizer-ci.com/g/russianidiot/public.py/

|




Install
```````


.. code:: bash

	`[sudo] pip install public`





Usage
`````


.. code:: python

	>>> from public import public
	
	>>> @public # decorator
	
	>>> public(*objects) # function



Examples
````````


.. code:: python

	>>> @public
		def func(): pass
	
	>>> @public
		class CLS: pass
	
	>>> print(__all__)
	['CLS',func']
	
	# public(*objects) function
	>>> public("name")
	>>> public("name1","name2")
	
	>>> print(__all__)
	['name','name1','name2']





Feedback |github_follow| |github_issues|

.. |github_follow| image:: https://img.shields.io/github/followers/russianidiot.svg?style=social&label=Follow
	:target: https://github.com/russianidiot

.. |github_issues| image:: https://img.shields.io/github/issues/russianidiot/public.py.svg
	:target: https://github.com/russianidiot/public.py/issues

